==> enough_ascii_art-0.9.3.tar.gz: lib/src/figlet/figlet.dart <==
import 'dart:io';
import 'dart:isolate';
import 'package:resource/resource.dart' show Resource;
import 'package:enough_ascii_art/src/figlet/parser.dart';
import 'package:enough_ascii_art/src/figlet/renderer.dart';

import 'font.dart';

/// Helper class to render a FIGure
class FIGlet {
  static Future<String> renderFIGureForFontName(
      String text, String fontName) async {
    fontName ??= 'cosmic';
    List<String> fontDefinition;
    try {
      var uri =
          Uri(scheme: 'package', path: 'lib/src/figlet/fonts/$fontName.flf');
      var resolvedUri = await Isolate.resolvePackageUri(uri);
      print('resolvedUri 1: $resolvedUri');

      uri =
          Uri(scheme: 'package', path: './lib/src/figlet/fonts/$fontName.flf');
      resolvedUri = await Isolate.resolvePackageUri(uri);
      print('resolvedUri 2: $resolvedUri');
      var resource = Resource('package:./lib/src/figlet/fonts/$fontName.flf');
      var text = await resource.readAsString();
      fontDefinition = text.split('\r\n');
      if (fontDefinition.length == 1) {
        fontDefinition = text.split('\n');
      }
    } catch (e) {
      print(e);
      fontDefinition =
          await File('./lib/src/figlet/fonts/$fontName.flf').readAsLines();
    }

    var parser = Parser();
    var font = parser.parseFontDefinition(fontDefinition);
    return renderFIGure(text, font);
  }

  static String renderFIGure(String text, Font font) {
    var renderer = Renderer();
    return renderer.render(text, font);
  }
}

==> enough_ascii_art-0.9.4.tar.gz: lib/src/figlet/figlet.dart <==
import 'dart:io';
import 'dart:isolate';
import 'package:resource/resource.dart' show Resource;
import 'package:enough_ascii_art/src/figlet/parser.dart';
import 'package:enough_ascii_art/src/figlet/renderer.dart';

import 'font.dart';

/// Helper class to render a FIGure
class FIGlet {
  static Future<String> renderFIGureForFontName(
      String text, String fontName) async {
    fontName ??= 'cosmic';
    List<String> fontDefinition;
    try {
      var uri =
          Uri(scheme: 'package', path: 'lib/src/figlet/fonts/$fontName.flf');
      var resolvedUri = await Isolate.resolvePackageUri(uri);
      print('resolvedUri 1: $resolvedUri');

      uri =
          Uri(scheme: 'package', path: './lib/src/figlet/fonts/$fontName.flf');
      resolvedUri = await Isolate.resolvePackageUri(uri);
      print('resolvedUri 2: $resolvedUri');
      uri = Uri(scheme: 'package', path: 'pubspec.yaml');
      resolvedUri = await Isolate.resolvePackageUri(uri);
      print('pubspec.yaml: $resolvedUri');
      uri = Uri(scheme: 'package', path: '.\\pubspec.yaml');
      resolvedUri = await Isolate.resolvePackageUri(uri);
      print('.\\pubspec.yaml: $resolvedUri');
      uri = Uri(scheme: 'package', path: './pubspec.yaml');
      resolvedUri = await Isolate.resolvePackageUri(uri);
      print('./pubspec.yaml: $resolvedUri');
      var resource = Resource('package:lib\\src\\figlet\\fonts\\$fontName.flf');
      var text = await resource.readAsString();
      fontDefinition = text.split('\r\n');
      if (fontDefinition.length == 1) {
        fontDefinition = text.split('\n');
      }
    } catch (e) {
      print(e);
      fontDefinition =
          await File('./lib/src/figlet/fonts/$fontName.flf').readAsLines();
    }

    var parser = Parser();
    var font = parser.parseFontDefinition(fontDefinition);
    return renderFIGure(text, font);
  }

  static String renderFIGure(String text, Font font) {
    var renderer = Renderer();
    return renderer.render(text, font);
  }
}
